@@ -3,13 +3,24 @@ package DBIx::Class::Result::Validation::VException;
 use strict;
 use warnings;
 use Moose;
+use overload '""' => sub {
+    require Carp;
+    Carp::longmess( shift->message );
+  },
+  fallback => 1;
 
 =head1 NAME
 
 DBIx::Class::Result::Validation::VException - Exception for Validation
 
+=head1 VERSION
+
+Version 0.11
+
 =cut
 
+our $VERSION = '0.11';
+
 =head1 SYNOPSIS
 
 DBIx::Class::Result::Validation::VException.
@@ -19,15 +30,17 @@ croak( DBIx::Class::Result::Validation::VException->new( message => "my message"
 =cut
 
 has object => (
-    is => 'rw',
+    is  => 'rw',
     isa => 'DBIx::Class::Row',
-#    required => 0,
+
+    #    required => 0,
 );
 
 has message => (
-    is => 'rw',
+    is  => 'rw',
     isa => 'Str',
-#    required => 0,
+
+    #    required => 0,
 );
 
 no Moose;
